within SHM.SeidelThesis.Components;
model SinusNode "Sinus node"
  parameter Real T_0 = 0.9 "heart period for denervated heart";
  parameter Real k_sNe = 1.2 "sensitivity of sinus node to concentration of Norepinephrine";
  parameter Real k_sAc = 0.2 "sensitivity of sinus node to concentration of Acetylcholine";
  Real phase(start=0,fixed=true) "heart cycle phase that rises from 0 to 1 (heartbeat generated) and is then reset to 0 again";
  SHM.Shared.Connectors.SubstanceConcentration sNe "postsynaptic concentration of Norepinephrine" annotation(Placement(visible = true, transformation(origin = {-40, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-40, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  SHM.Shared.Connectors.SubstanceConcentration sAc "postsynaptic concentration of Acetylcholine" annotation(Placement(visible = true, transformation(origin = {40, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {40, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  SHM.Shared.Connectors.ExcitationOutput signal "output signal generated by the sinus node" annotation(Placement(visible = true, transformation(origin = {0, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
protected
  parameter Real pemean = SHM.SeidelThesis.Functions.PEMean(100) "mean of the phase effectiveness function over the interval [0,1]";
  Boolean signal0(start=false,fixed=true) "base signal of the sinus node";
equation
  der(phase) = 1/T_0 * (1 + k_sNe * sNe.concentration - k_sAc * sAc.concentration * SHM.SeidelThesis.Functions.PhaseEffectiveness(phase)/pemean);
  sNe.rate = 0;
  sAc.rate = 0;
  when phase > 1 then
    reinit(phase,0);
    signal0 = not pre(signal0);
  end when;
  signal = change(signal0);
annotation(Documentation(info="<html>
  <p>Models the sinus node as an integrate-and-fire model with postsynaptic concentrations of Norepinephrine and Acetylcholine as input.</p>
  <p>The effect of Acetylcholine is additionally modulated by a phase effectiveness curve.</p>
</html>"), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {1, 1})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {1, 1}), graphics = {Ellipse(origin = {-0.158344, 0.48068}, fillColor = {255, 255, 255}, extent = {{-79.375, -79.375}, {79.375, 79.375}}, endAngle = 360), Line(origin = {-2.27393, 7.79068}, points = {{-71.3692, -24.1544}, {-38.0955, 24.8617}, {-38.0955, -25.2277}, {-7.68408, 24.8617}, {-7.68408, -25.2277}, {22.0118, 24.8617}, {22.0118, -23.7966}, {52.4233, 25.2195}, {52.4233, -24.5122}, {71.3857, 6.97263}}, thickness = 2), Line(origin = {-22.2939, -49.6393}, points = {{-18.4258, 25.7603}, {-18.4258, -3.9356}, {22.1482, -3.9356}, {22.2592, -21.3519}}, pattern = LinePattern.Dash, thickness = 1, arrow = {Arrow.None, Arrow.Filled}), Line(origin = {-32.8383, -21.0004}, points = {{5.44247, 5.65551}, {0.63654, -2.22572}, {0.17224, 3.65356}, {-4.67192, -4.67192}}, color = {255, 170, 0}, thickness = 1.5, arrow = {Arrow.None, Arrow.Filled}, arrowSize = 4), Line(origin = {5.25607, 42.6607}, points = {{-14.8479, 0}, {14.8479, 0}}, thickness = 1), Line(origin = {20.0961, 42.6336}, points = {{0, 5.72451}, {0, -5.72451}}, thickness = 1), Line(origin = {-9.6177, 42.645}, points = {{0, 5.72451}, {0, -5.72451}}, thickness = 1), Line(origin = {-18.929, 56.5985}, points = {{-16.192, 10.3216}, {16.192, -10.3216}}, thickness = 1, arrow = {Arrow.None, Arrow.Filled}), Line(origin = {20.1661, 56.4707}, points = {{9.35393, 9.41844}, {-9.35393, -9.41844}}, thickness = 1, arrow = {Arrow.None, Arrow.Filled}), Text(origin = {9.26117, 59.1162}, extent = {{-5.16, 4.45}, {10.9659, -9.09471}}, textString = "+"), Text(origin = {-6.47333, 58.0636}, extent = {{-5.16, 4.45}, {10.97, -9.09}}, textString = "-")}));
end SinusNode;
